==> cohesity_management_sdk-1.6.9.tar.gz: cohesity_management_sdk-1.6.9/cohesity_management_sdk/models/vault_type_vault_provider_stats_info_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Cohesity Inc.

class VaultTypeVaultProviderStatsInfoEnum(object):

    """Implementation of the 'VaultType_VaultProviderStatsInfo' enum.

    Specifies the External Target type.

    Attributes:
        KAMAZON: TODO: type description here.
        KORACLETIERARCHIVE: TODO: type description here.
        KCOLDLINE: TODO: type description here.
        KNEARLINE: TODO: type description here.
        KQSTARTAPE: TODO: type description here.
        KGOOGLEDRA: TODO: type description here.
        KS3: TODO: type description here.
        KAZURE: TODO: type description here.
        KORACLETIERSTANDARD: TODO: type description here.
        KNAS: TODO: type description here.
        KORACLE: TODO: type description here.
        KGLACIER: TODO: type description here.
        KGOOGLESTANDARD: TODO: type description here.
        KAZUREARCHIVE: TODO: type description here.
        KAMAZONS3STANDARDIA: TODO: type description here.
        KS3COMPATIBLE: TODO: type description here.
        KAZURESTANDARD: TODO: type description here.
        KGOOGLE: TODO: type description here.
        KAWSGOVCLOUD: TODO: type description here.
        KAZUREGOVCLOUD: TODO: type description here.
        KAMAZONC2S: TODO: type description here.

    """

    KAMAZON = 'kAmazon'

    KORACLETIERARCHIVE = 'kOracleTierArchive'

    KCOLDLINE = 'kColdline'

    KNEARLINE = 'kNearline'

    KQSTARTAPE = 'kQStarTape'

    KGOOGLEDRA = 'kGoogleDRA'

    KS3 = 'kS3'

    KAZURE = 'kAzure'

    KORACLETIERSTANDARD = 'kOracleTierStandard'

    KNAS = 'kNAS'

    KORACLE = 'kOracle'

    KGLACIER = 'kGlacier'

    KGOOGLESTANDARD = 'kGoogleStandard'

    KAZUREARCHIVE = 'kAzureArchive'

    KAMAZONS3STANDARDIA = 'kAmazonS3StandardIA'

    KS3COMPATIBLE = 'kS3Compatible'

    KAZURESTANDARD = 'kAzureStandard'

    KGOOGLE = 'kGoogle'

    KAWS_GO_VCLOUD = 'kAWSGovCloud'

    K_AZURE_GO_VCLOUD = 'kAzureGovCloud'

    KAMAZONC2S = 'kAmazonC2S'

==> cohesity_management_sdk-1.9.2.tar.gz: cohesity_management_sdk-1.9.2/cohesity_management_sdk/models/vault_type_vault_provider_stats_info_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class VaultTypeVaultProviderStatsInfoEnum(object):

    """Implementation of the 'VaultTypeVaultProviderStatsInfo' enum.
    Specifies the External Target type.


    Attributes:
        KNEARLINE: TODO: type description here.
        KGLACIER: TODO: type description here.
        KS3: TODO: type description here.
        KAZURESTANDARD: TODO: type description here.
        KS3COMPATIBLE: TODO: type description here.
        KQSTARTAPE: TODO: type description here.
        KGOOGLESTANDARD: TODO: type description here.
        KGOOGLEDRA: TODO: type description here.
        KAMAZONS3STANDARDIA: TODO: type description here.
        KAWSGOVCLOUD: TODO: type description here.
        KNAS: TODO: type description here.
        KCOLDLINE: TODO: type description here.
        KAZUREGOVCLOUD: TODO: type description here.
        KAZUREARCHIVE: TODO: type description here.
        KAZURE: TODO: type description here.
        KGOOGLE: TODO: type description here.
        KAMAZON: TODO: type description here.
        KORACLE: TODO: type description here.
        KORACLETIERSTANDARD: TODO: type description here.
        KORACLETIERARCHIVE: TODO: type description here.
        KAMAZONC2S: TODO: type description here.

    """

    KNEARLINE = 'kNearline'

    KGLACIER = 'kGlacier'

    KS3 = 'kS3'

    KAZURESTANDARD = 'kAzureStandard'

    KS3COMPATIBLE = 'kS3Compatible'

    KQSTARTAPE = 'kQStarTape'

    KGOOGLESTANDARD = 'kGoogleStandard'

    KGOOGLEDRA = 'kGoogleDRA'

    KAMAZONS3STANDARDIA = 'kAmazonS3StandardIA'

    KAWS_GOV_CLOUD = 'kAWSGovCloud'

    KNAS = 'kNAS'

    KCOLDLINE = 'kColdline'

    K_AZURE_GOV_CLOUD = 'kAzureGovCloud'

    KAZUREARCHIVE = 'kAzureArchive'

    KAZURE = 'kAzure'

    KGOOGLE = 'kGoogle'

    KAMAZON = 'kAmazon'

    KORACLE = 'kOracle'

    KORACLETIERSTANDARD = 'kOracleTierStandard'

    KORACLETIERARCHIVE = 'kOracleTierArchive'

    KAMAZONC2S = 'kAmazonC2S'
